@@ -1,6 +1,16 @@
-distribution.random<-function(design,statistic,save="no",number,limit,data=read.table(file.choose(new=FALSE)),starts=file.choose(new=FALSE)){
+distribution.random <-
+function(
+  design,
+  statistic,
+  save="no",
+  number,
+  limit,
+  data=read.table(file.choose(new=FALSE)),
+  starts=file.choose(new=FALSE),
+  assignments=file.choose(new=FALSE)
+){
 
-obs <- data[,2]
+  obs <- data[,2]
 
   if(design=="CRD"){
     if(save=="yes"){
@@ -634,4 +644,45 @@ obs <- data[,2]
     }
   }
 
+  if(design=="Custom"){
+    if(!(statistic=="A-B"||statistic=="B-A"||statistic=="|A-B|"))
+      stop("Chosen test statistic not allowed for this design.")
+    
+    if(save=="yes"){
+      file<-file.choose(new=FALSE)
+    }
+    
+    observed<-data[,2]
+    assignments<-read.table(assignments)
+    selection<-sample.int(nrow(assignments),number,replace=TRUE)
+    
+    scores.a<-list()
+    for(it in 1:number)
+      scores.a[[it]]<-c(observed[assignments[selection[it],]=="A"])
+    
+    scores.b<-list()
+    for(it in 1:number)
+      scores.b[[it]]<-c(observed[assignments[selection[it],]=="B"])
+    
+    distribution<-numeric(number)
+    if(statistic=="A-B"){
+      for(it in 1:number)
+        distribution[it]<-mean(scores.a[[it]])-mean(scores.b[[it]])
+    }
+    if(statistic=="B-A"){
+      for(it in 1:number)
+        distribution[it]<-mean(scores.b[[it]])-mean(scores.a[[it]])
+    }
+    if(statistic=="|A-B|"){
+      for(it in 1:number)
+        distribution[it]<-abs(mean(scores.a[[it]])-mean(scores.b[[it]]))
+    }
+    
+    distribution<-sort(distribution)
+    if(save=="yes")
+      write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
+    
+    return(distribution)
+  }
+  
 }
