@@ -1,6 +1,16 @@
-pvalue.random<-function(design,statistic,save="no",number,limit,data=read.table(file.choose(new=FALSE)),starts=file.choose(new=FALSE)){
+pvalue.random <-
+function(
+  design,
+  statistic,
+  save="no",
+  number,
+  limit,
+  data=read.table(file.choose(new=FALSE)),
+  starts=file.choose(new=FALSE),
+  assignments=file.choose(new=FALSE)
+){
 
-obs <- data[,2]
+  obs <- data[,2]
 
   if(design=="CRD"){
     if(save=="yes"){
@@ -722,5 +732,54 @@ obs <- data[,2]
       unlink(fileCOMBSTARTPTS,recursive=FALSE)
     }
   }
+  
+  if(design=="Custom"){
+    if(!(statistic=="A-B"||statistic=="B-A"||statistic=="|A-B|"))
+      stop("Chosen test statistic not allowed for this design.")
+    
+    if(save=="yes"){
+      file<-file.choose(new=FALSE)
+    }
+    
+    observed<-data[,2]
+    observed.a<-data[,2][data[,1]=="A"]
+    observed.b<-data[,2][data[,1]=="B"]
+    assignments<-read.table(assignments)
+    selection<-sample.int(nrow(assignments),number,replace=TRUE)
+    
+    scores.a<-list()
+    for(it in 1:number)
+      scores.a[[it]]<-c(observed[assignments[selection[it],]=="A"])
+    
+    scores.b<-list()
+    for(it in 1:number)
+      scores.b[[it]]<-c(observed[assignments[selection[it],]=="B"])
+    
+    distribution<-numeric(number)
+    if(statistic=="A-B"){
+      for(it in 1:number)
+        distribution[it]<-mean(scores.a[[it]])-mean(scores.b[[it]])
+      observed.statistic<-mean(observed.a)-mean(observed.b)
+    }
+    if(statistic=="B-A"){
+      for(it in 1:number)
+        distribution[it]<-mean(scores.b[[it]])-mean(scores.a[[it]])
+      observed.statistic<-mean(observed.b)-mean(observed.a)
+    }
+    if(statistic=="|A-B|"){
+      for(it in 1:number)
+        distribution[it]<-abs(mean(scores.a[[it]])-mean(scores.b[[it]]))
+      observed.statistic<-abs(mean(observed.a)-mean(observed.b))
+    }
+    
+    distribution<-sort(distribution)
+    test<-distribution>=observed.statistic
+    p.value<-sum(test)/number
+    
+    if(save=="yes")
+      write.table(distribution,file=file,col.names=FALSE,row.names=FALSE,append=FALSE)
+    
+    return(p.value)
+  }
 
 }
